@@ -1,6 +1,5 @@
 import logging
 import select
-import socket
 import threading
 
 import aprslib
@@ -13,6 +12,7 @@ import wrapt
 
 import aprsd
 from aprsd import stats
+from aprsd.packets import core
 
 
 LOG = logging.getLogger("APRSD")
@@ -32,28 +32,10 @@ class Aprsdis(aprslib.IS):
         self.thread_stop = True
         LOG.info("Shutdown Aprsdis client.")
 
-    def is_socket_closed(self, sock: socket.socket) -> bool:
-        try:
-            # this will try to read bytes without blocking and also without removing them from buffer (peek only)
-            data = sock.recv(16, socket.MSG_DONTWAIT | socket.MSG_PEEK)
-            if len(data) == 0:
-                return True
-        except BlockingIOError:
-            return False  # socket is open and reading from it would block
-        except ConnectionResetError:
-            return True  # socket was closed for some other reason
-        except Exception:
-            self.logger.exception(
-                "unexpected exception when checking if a socket is closed",
-            )
-            return False
-        return False
-
     @wrapt.synchronized(lock)
-    def send(self, msg):
+    def send(self, packet: core.Packet):
         """Send an APRS Message object."""
-        line = str(msg)
-        self.sendall(line)
+        self.sendall(packet.raw)
 
     def _socket_readlines(self, blocking=False):
         """
