@@ -1,22 +1,22 @@
 # The base plugin class
 import abc
-import fnmatch
 import importlib
 import inspect
 import logging
-import os
 import re
 import textwrap
 import threading
 
+from oslo_config import cfg
 import pluggy
-from thesmuggler import smuggle
 
 import aprsd
-from aprsd import client, messaging, packets, threads
+from aprsd import client, packets, threads
+from aprsd.packets import watch_list
 
 
 # setup the global logger
+CONF = cfg.CONF
 LOG = logging.getLogger("APRSD")
 
 CORE_MESSAGE_PLUGINS = [
@@ -42,7 +42,7 @@ class APRSDPluginSpec:
     """A hook specification namespace."""
 
     @hookspec
-    def filter(self, packet):
+    def filter(self, packet: packets.core.Packet):
         """My special little hook that you can customize."""
 
 
@@ -59,8 +59,7 @@ class APRSDPluginBase(metaclass=abc.ABCMeta):
     # Set this in setup()
     enabled = False
 
-    def __init__(self, config):
-        self.config = config
+    def __init__(self):
         self.message_counter = 0
         self.setup()
         self.threads = self.create_threads() or []
@@ -119,11 +118,11 @@ class APRSDPluginBase(metaclass=abc.ABCMeta):
                 thread.stop()
 
     @abc.abstractmethod
-    def filter(self, packet):
+    def filter(self, packet: packets.core.Packet):
         pass
 
     @abc.abstractmethod
-    def process(self, packet):
+    def process(self, packet: packets.core.Packet):
         """This is called when the filter passes."""
 
 
@@ -142,15 +141,10 @@ class APRSDWatchListPluginBase(APRSDPluginBase, metaclass=abc.ABCMeta):
     def setup(self):
         # if we have a watch list enabled, we need to add filtering
         # to enable seeing packets from the watch list.
-        if "watch_list" in self.config["aprsd"] and self.config["aprsd"][
-            "watch_list"
-        ].get("enabled", False):
+        if CONF.watch_list.enabled:
             # watch list is enabled
             self.enabled = True
-            watch_list = self.config["aprsd"]["watch_list"].get(
-                "callsigns",
-                [],
-            )
+            watch_list = CONF.watch_list.callsigns
             # make sure the timeout is set or this doesn't work
             if watch_list:
                 aprs_client = client.factory.create().client
@@ -160,11 +154,11 @@ class APRSDWatchListPluginBase(APRSDPluginBase, metaclass=abc.ABCMeta):
                 LOG.warning("Watch list enabled, but no callsigns set.")
 
     @hookimpl
-    def filter(self, packet):
-        result = messaging.NULL_MESSAGE
+    def filter(self, packet: packets.core.Packet):
+        result = packets.NULL_MESSAGE
         if self.enabled:
-            wl = packets.WatchList()
-            if wl.callsign_in_watchlist(packet["from"]):
+            wl = watch_list.WatchList()
+            if wl.callsign_in_watchlist(packet.from_call):
                 # packet is from a callsign in the watch list
                 self.rx_inc()
                 try:
@@ -212,37 +206,41 @@ class APRSDRegexCommandPluginBase(APRSDPluginBase, metaclass=abc.ABCMeta):
         self.enabled = True
 
     @hookimpl
-    def filter(self, packet):
+    def filter(self, packet: packets.core.MessagePacket):
+        if not self.enabled:
+            result = f"{self.__class__.__name__} isn't enabled"
+            LOG.warning(result)
+            return result
+
+        if not isinstance(packet, packets.core.MessagePacket):
+            LOG.warning(f"Got a {packet.__class__.__name__} ignoring")
+            return packets.NULL_MESSAGE
+
         result = None
 
-        message = packet.get("message_text", None)
-        msg_format = packet.get("format", None)
-        tocall = packet.get("addresse", None)
+        message = packet.message_text
+        tocall = packet.to_call
 
         # Only process messages destined for us
         # and is an APRS message format and has a message.
         if (
-            tocall == self.config["aprs"]["login"]
-            and msg_format == "message"
+            tocall == CONF.callsign
+            and isinstance(packet, packets.core.MessagePacket)
             and message
         ):
-            if re.search(self.command_regex, message):
+            if re.search(self.command_regex, message, re.IGNORECASE):
                 self.rx_inc()
-                if self.enabled:
-                    try:
-                        result = self.process(packet)
-                    except Exception as ex:
-                        LOG.error(
-                            "Plugin {} failed to process packet {}".format(
-                                self.__class__, ex,
-                            ),
-                        )
-                        LOG.exception(ex)
-                    if result:
-                        self.tx_inc()
-                else:
-                    result = f"{self.__class__.__name__} isn't enabled"
-                    LOG.warning(result)
+                try:
+                    result = self.process(packet)
+                except Exception as ex:
+                    LOG.error(
+                        "Plugin {} failed to process packet {}".format(
+                            self.__class__, ex,
+                        ),
+                    )
+                    LOG.exception(ex)
+                if result:
+                    self.tx_inc()
 
         return result
 
@@ -251,12 +249,11 @@ class APRSFIKEYMixin:
     """Mixin class to enable checking the existence of the aprs.fi apiKey."""
 
     def ensure_aprs_fi_key(self):
-        try:
-            self.config.check_option(["services", "aprs.fi", "apiKey"])
-            self.enabled = True
-        except Exception as ex:
-            LOG.error(f"Failed to find config aprs.fi:apikey {ex}")
+        if not CONF.aprs_fi.apiKey:
+            LOG.error("Config aprs_fi.apiKey is not set")
             self.enabled = False
+        else:
+            self.enabled = True
 
 
 class HelpPlugin(APRSDRegexCommandPluginBase):
@@ -265,17 +262,16 @@ class HelpPlugin(APRSDRegexCommandPluginBase):
     This plugin is in this file to prevent a circular import.
     """
 
-    version = "1.0"
     command_regex = "^[hH]"
     command_name = "help"
 
     def help(self):
         return "Help: send APRS help or help <plugin>"
 
-    def process(self, packet):
+    def process(self, packet: packets.core.MessagePacket):
         LOG.info("HelpPlugin")
         # fromcall = packet.get("from")
-        message = packet.get("message_text", None)
+        message = packet.message_text
         # ack = packet.get("msgNo", "0")
         a = re.search(r"^.*\s+(.*)", message)
         command_name = None
@@ -325,6 +321,8 @@ class PluginManager:
 
     # the pluggy PluginManager for all Message plugins
     _pluggy_pm = None
+    # the pluggy PluginManager for all WatchList plugins
+    _watchlist_pm = None
 
     # aprsd config dict
     config = None
@@ -347,29 +345,9 @@ class PluginManager:
     def _init(self):
         self._pluggy_pm = pluggy.PluginManager("aprsd")
         self._pluggy_pm.add_hookspecs(APRSDPluginSpec)
-
-    def load_plugins_from_path(self, module_path):
-        if not os.path.exists(module_path):
-            LOG.error(f"plugin path '{module_path}' doesn't exist.")
-            return None
-
-        dir_path = os.path.realpath(module_path)
-        pattern = "*.py"
-
-        self.obj_list = []
-
-        for path, _subdirs, files in os.walk(dir_path):
-            for name in files:
-                if fnmatch.fnmatch(name, pattern):
-                    LOG.debug(f"MODULE? '{name}' '{path}'")
-                    module = smuggle(f"{path}/{name}")
-                    for mem_name, obj in inspect.getmembers(module):
-                        if inspect.isclass(obj) and self.is_plugin(obj):
-                            self.obj_list.append(
-                                {"name": mem_name, "obj": obj(self.config)},
-                            )
-
-        return self.obj_list
+        # For the watchlist plugins
+        self._watchlist_pm = pluggy.PluginManager("aprsd")
+        self._watchlist_pm.add_hookspecs(APRSDPluginSpec)
 
     def is_plugin(self, obj):
         for c in inspect.getmro(obj):
@@ -391,12 +369,17 @@ class PluginManager:
         :param kwargs: parameters to pass
         :return:
         """
-        module_name, class_name = module_class_string.rsplit(".", 1)
+        module_name = None
+        class_name = None
         try:
+            module_name, class_name = module_class_string.rsplit(".", 1)
             module = importlib.import_module(module_name)
             module = importlib.reload(module)
         except Exception as ex:
-            LOG.error(f"Failed to load Plugin '{module_name}' : '{ex}'")
+            if not module_name:
+                LOG.error(f"Failed to load Plugin {module_class_string}")
+            else:
+                LOG.error(f"Failed to load Plugin '{module_name}' : '{ex}'")
             return
 
         assert hasattr(module, class_name), "class {} is not in {}".format(
@@ -426,16 +409,31 @@ class PluginManager:
             plugin_obj = self._create_class(
                 plugin_name,
                 APRSDPluginBase,
-                config=self.config,
             )
             if plugin_obj:
-                LOG.info(
-                    "Registering plugin '{}'({})".format(
-                        plugin_name,
-                        plugin_obj.version,
-                    ),
-                )
-                self._pluggy_pm.register(plugin_obj)
+                if isinstance(plugin_obj, APRSDWatchListPluginBase):
+                    if plugin_obj.enabled:
+                        LOG.info(
+                            "Registering WatchList plugin '{}'({})".format(
+                                plugin_name,
+                                plugin_obj.version,
+                            ),
+                        )
+                        self._watchlist_pm.register(plugin_obj)
+                    else:
+                        LOG.warning(f"Plugin {plugin_obj.__class__.__name__} is disabled")
+                else:
+                    if plugin_obj.enabled:
+                        LOG.info(
+                            "Registering plugin '{}'({}) -- {}".format(
+                                plugin_name,
+                                plugin_obj.version,
+                                plugin_obj.command_regex,
+                            ),
+                        )
+                        self._pluggy_pm.register(plugin_obj)
+                    else:
+                        LOG.warning(f"Plugin {plugin_obj.__class__.__name__} is disabled")
         except Exception as ex:
             LOG.error(f"Couldn't load plugin '{plugin_name}'")
             LOG.exception(ex)
@@ -451,10 +449,10 @@ class PluginManager:
         LOG.info("Loading APRSD Plugins")
         self._init()
         # Help plugin is always enabled.
-        _help = HelpPlugin(self.config)
+        _help = HelpPlugin()
         self._pluggy_pm.register(_help)
 
-        enabled_plugins = self.config["aprsd"].get("enabled_plugins", None)
+        enabled_plugins = CONF.enabled_plugins
         if enabled_plugins:
             for p_name in enabled_plugins:
                 self._load_plugin(p_name)
@@ -464,22 +462,17 @@ class PluginManager:
             for p_name in CORE_MESSAGE_PLUGINS:
                 self._load_plugin(p_name)
 
-        if self.config["aprsd"]["watch_list"].get("enabled", False):
-            LOG.info("Loading APRSD WatchList Plugins")
-            enabled_notify_plugins = self.config["aprsd"]["watch_list"].get(
-                "enabled_plugins",
-                None,
-            )
-            if enabled_notify_plugins:
-                for p_name in enabled_notify_plugins:
-                    self._load_plugin(p_name)
         LOG.info("Completed Plugin Loading.")
 
-    def run(self, packet):
+    def run(self, packet: packets.core.MessagePacket):
         """Execute all the pluguns run method."""
         with self.lock:
             return self._pluggy_pm.hook.filter(packet=packet)
 
+    def run_watchlist(self, packet: packets.core.Packet):
+        with self.lock:
+            return self._watchlist_pm.hook.filter(packet=packet)
+
     def stop(self):
         """Stop all threads created by all plugins."""
         with self.lock:
@@ -492,5 +485,26 @@ class PluginManager:
         self._pluggy_pm.register(obj)
 
     def get_plugins(self):
+        plugin_list = []
         if self._pluggy_pm:
-            return self._pluggy_pm.get_plugins()
+            for plug in self._pluggy_pm.get_plugins():
+                plugin_list.append(plug)
+        if self._watchlist_pm:
+            for plug in self._watchlist_pm.get_plugins():
+                plugin_list.append(plug)
+
+        return plugin_list
+
+    def get_watchlist_plugins(self):
+        pl = []
+        if self._watchlist_pm:
+            for plug in self._watchlist_pm.get_plugins():
+                pl.append(plug)
+        return pl
+
+    def get_message_plugins(self):
+        pl = []
+        if self._pluggy_pm:
+            for plug in self._pluggy_pm.get_plugins():
+                pl.append(plug)
+        return pl
